@@ -13,21 +13,22 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <string.h>
 #include <stdint.h>
 #include <assert.h>
 #include <math.h>
 
-#include "babl.h"
-#include "babl-ids.h"
+#include "babl-internal.h"
 #include "babl-base.h"
 
 
-static inline long
-convert_double_u16_scaled (double   min_val,
+static inline void
+convert_double_u16_scaled (BablConversion *conversion,
+                           double   min_val,
                            double   max_val,
                            uint16_t min,
                            uint16_t max,
@@ -53,11 +54,11 @@ convert_double_u16_scaled (double   min_val,
       dst              += dst_pitch;
       src              += src_pitch;
     }
-  return n;
 }
 
-static inline long
-convert_u16_double_scaled (double   min_val,
+static inline void
+convert_u16_double_scaled (BablConversion *conversion,
+                           double   min_val,
                            double   max_val,
                            uint16_t min,
                            uint16_t max,
@@ -83,32 +84,31 @@ convert_u16_double_scaled (double   min_val,
       dst              += dst_pitch;
       src              += src_pitch;
     }
-  return n;
 }
 
 #define MAKE_CONVERSIONS(name, min_val, max_val, min, max)      \
-  static long \
-  convert_ ## name ## _double (void *src, \
+  static void \
+  convert_ ## name ## _double (BablConversion *c, void *src, \
                                void *dst, \
                                int src_pitch, \
                                int dst_pitch, \
                                long n)                               \
   { \
-    return convert_u16_double_scaled (min_val, max_val, min, max, \
-                                      src, dst, src_pitch, dst_pitch, n); \
+    convert_u16_double_scaled (c, min_val, max_val, min, max, \
+                               src, dst, src_pitch, dst_pitch, n); \
   }                                                               \
-  static long \
-  convert_double_ ## name (void *src, \
+  static void \
+  convert_double_ ## name (BablConversion *c, void *src, \
                            void *dst, \
                            int src_pitch, \
                            int dst_pitch, \
                            long n)                                 \
   { \
-    return convert_double_u16_scaled (min_val, max_val, min, max, \
-                                      src, dst, src_pitch, dst_pitch, n); \
+    convert_double_u16_scaled (c, min_val, max_val, min, max, \
+                               src, dst, src_pitch, dst_pitch, n); \
   }
 
-MAKE_CONVERSIONS (u16, 0.0, 1.0, 0, UINT16_MAX);
+MAKE_CONVERSIONS (u16, 0.0, 1.0, 0, UINT16_MAX)
 
 void
 babl_base_type_u16 (void)
@@ -120,15 +120,15 @@ babl_base_type_u16 (void)
     NULL);
 
   babl_conversion_new (
-    babl_type_id (BABL_U16),
-    babl_type_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_U16),
+    babl_type_from_id (BABL_DOUBLE),
     "plane", convert_u16_double,
     NULL
   );
 
   babl_conversion_new (
-    babl_type_id (BABL_DOUBLE),
-    babl_type_id (BABL_U16),
+    babl_type_from_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_U16),
     "plane", convert_double_u16,
     NULL
   );
